pub struct MemoryPermissionsClient { /* private fields */ }Expand description
Permissions service client for memory transport. All methods are synchronous and use the -sys safe layer.
Implementations
Sourceimpl MemoryPermissionsClient
impl MemoryPermissionsClient
Sourcepub fn check_permission(
&self,
request: &CheckPermissionRequest,
) -> Result<CheckPermissionResponse, SpiceDBError>
pub fn check_permission( &self, request: &CheckPermissionRequest, ) -> Result<CheckPermissionResponse, SpiceDBError>
Sourcepub fn write_relationships(
&self,
request: &WriteRelationshipsRequest,
) -> Result<WriteRelationshipsResponse, SpiceDBError>
pub fn write_relationships( &self, request: &WriteRelationshipsRequest, ) -> Result<WriteRelationshipsResponse, SpiceDBError>
WriteRelationships.
Errors
Returns an error if the FFI call fails or the response cannot be decoded.
Sourcepub fn delete_relationships(
&self,
request: &DeleteRelationshipsRequest,
) -> Result<DeleteRelationshipsResponse, SpiceDBError>
pub fn delete_relationships( &self, request: &DeleteRelationshipsRequest, ) -> Result<DeleteRelationshipsResponse, SpiceDBError>
DeleteRelationships.
Errors
Returns an error if the FFI call fails or the response cannot be decoded.
Sourcepub fn check_bulk_permissions(
&self,
request: &CheckBulkPermissionsRequest,
) -> Result<CheckBulkPermissionsResponse, SpiceDBError>
pub fn check_bulk_permissions( &self, request: &CheckBulkPermissionsRequest, ) -> Result<CheckBulkPermissionsResponse, SpiceDBError>
CheckBulkPermissions.
Errors
Returns an error if the FFI call fails or the response cannot be decoded.
Sourcepub fn expand_permission_tree(
&self,
request: &ExpandPermissionTreeRequest,
) -> Result<ExpandPermissionTreeResponse, SpiceDBError>
pub fn expand_permission_tree( &self, request: &ExpandPermissionTreeRequest, ) -> Result<ExpandPermissionTreeResponse, SpiceDBError>
ExpandPermissionTree.
Errors
Returns an error if the FFI call fails or the response cannot be decoded.