pub struct CheckBulkPermissionsResponseItem {
pub permissionship: i32,
pub partial_caveat_info: Option<PartialCaveatInfo>,
pub debug_trace: Option<DebugInformation>,
}Fields
permissionship: i32partial_caveat_info: Option<PartialCaveatInfo>debug_trace: Option<DebugInformation>debug_trace is the debugging trace of this check, if requested.
Implementations
Sourceimpl CheckBulkPermissionsResponseItem
impl CheckBulkPermissionsResponseItem
Sourcepub fn permissionship(&self) -> Permissionship
pub fn permissionship(&self) -> Permissionship
Returns the enum value of permissionship, or the default if the field is set to an invalid enum value.
Sourcepub fn set_permissionship(&mut self, value: Permissionship)
pub fn set_permissionship(&mut self, value: Permissionship)
Sets permissionship to the provided enum value.