pub struct ImportBulkRelationshipsResponse {
pub num_loaded: u64,
}Expand description
ImportBulkRelationshipsResponse is returned on successful completion of the bulk load stream, and contains the total number of relationships loaded.
Fields
num_loaded: u64Trait Implementations
Sourceimpl Clone for ImportBulkRelationshipsResponse
impl Clone for ImportBulkRelationshipsResponse
Sourcefn clone(&self) -> ImportBulkRelationshipsResponse
fn clone(&self) -> ImportBulkRelationshipsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ImportBulkRelationshipsResponse
impl Default for ImportBulkRelationshipsResponse
Sourcefn default() -> ImportBulkRelationshipsResponse
fn default() -> ImportBulkRelationshipsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ImportBulkRelationshipsResponse
impl Message for ImportBulkRelationshipsResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ImportBulkRelationshipsResponse
impl PartialEq for ImportBulkRelationshipsResponse
Sourcefn eq(&self, other: &ImportBulkRelationshipsResponse) -> bool
fn eq(&self, other: &ImportBulkRelationshipsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for ImportBulkRelationshipsResponse
impl Eq for ImportBulkRelationshipsResponse
impl StructuralPartialEq for ImportBulkRelationshipsResponse