RelationshipFilter

Struct RelationshipFilter 

pub struct RelationshipFilter {
    pub resource_type: String,
    pub optional_resource_id: String,
    pub optional_resource_id_prefix: String,
    pub optional_relation: String,
    pub optional_subject_filter: Option<SubjectFilter>,
}
RelationshipFilter is a collection of filters which when applied to a relationship will return relationships that have exactly matching fields.

All fields are optional and if left unspecified will not filter relationships, but at least one field must be specified.

NOTE: The performance of the API will be affected by the selection of fields on which to filter. If a field is not indexed, the performance of the API can be significantly slower.

Fields

resource_type: String

resource_type is the optional resource type of the relationship. NOTE: It is not prefixed with “optional_” for legacy compatibility.

optional_resource_id: String

optional_resource_id is the optional resource ID of the relationship. If specified, optional_resource_id_prefix cannot be specified.

optional_resource_id_prefix: String

optional_resource_id_prefix is the optional prefix for the resource ID of the relationship. If specified, optional_resource_id cannot be specified.

optional_relation: String

relation is the optional relation of the relationship.

optional_subject_filter: Option<SubjectFilter>

optional_subject_filter is the optional filter for the subjects of the relationships.