SubjectFilter

Struct SubjectFilter 

pub struct SubjectFilter {
    pub subject_type: String,
    pub optional_subject_id: String,
    pub optional_relation: Option<RelationFilter>,
}
SubjectFilter specifies a filter on the subject of a relationship.

subject_type is required and all other fields are optional, and will not impose any additional requirements if left unspecified.

Fields

subject_type: Stringoptional_subject_id: Stringoptional_relation: Option<RelationFilter>