pub struct LookupSubjectsRequest {
pub consistency: Option<Consistency>,
pub resource: Option<ObjectReference>,
pub permission: String,
pub subject_object_type: String,
pub optional_subject_relation: String,
pub context: Option<Struct>,
pub optional_concrete_limit: u32,
pub optional_cursor: Option<Cursor>,
pub wildcard_option: i32,
}Expand description
LookupSubjectsRequest performs a lookup of all subjects of a particular kind for which the subject has the specified permission or the relation in which the subject exists, streaming back the IDs of those subjects.
Fields
consistency: Option<Consistency>resource: Option<ObjectReference>resource is the resource for which all matching subjects for the permission or relation will be returned.
permission: Stringpermission is the name of the permission (or relation) for which to find the subjects.
subject_object_type: Stringsubject_object_type is the type of subject object for which the IDs will be returned.
optional_subject_relation: Stringoptional_subject_relation is the optional relation for the subject.
context: Option<Struct>context consists of named values that are injected into the caveat evaluation context
optional_concrete_limit: u32optional_concrete_limit is currently unimplemented for LookupSubjects and will return an error as of SpiceDB version 1.40.1. This will be implemented in a future version of SpiceDB.
optional_cursor: Option<Cursor>optional_cursor is currently unimplemented for LookupSubjects and will be ignored as of SpiceDB version 1.40.1. This will be implemented in a future version of SpiceDB.
wildcard_option: i32wildcard_option specifies whether wildcards should be returned by LookupSubjects. For backwards compatibility, defaults to WILDCARD_OPTION_INCLUDE_WILDCARDS if unspecified.
Implementations
Sourceimpl LookupSubjectsRequest
impl LookupSubjectsRequest
Sourcepub fn wildcard_option(&self) -> WildcardOption
pub fn wildcard_option(&self) -> WildcardOption
Returns the enum value of wildcard_option, or the default if the field is set to an invalid enum value.
Sourcepub fn set_wildcard_option(&mut self, value: WildcardOption)
pub fn set_wildcard_option(&mut self, value: WildcardOption)
Sets wildcard_option to the provided enum value.